From 03a375fa07b0c971069557c4cd204d8e284f302d Mon Sep 17 00:00:00 2001
From: Simon Lang <simon.lang@outlook.com>
Date: Wed, 10 Jun 2020 22:01:02 +0100
Subject: [PATCH] * lisp/progmodes/grep.el (grep-match-regexp): New variable.
 (grep-filter): Use it.

---
 doc/emacs/building.texi | 4 ++++
 etc/NEWS                | 8 ++++++++
 lisp/progmodes/grep.el  | 9 ++++++++-
 3 files changed, 20 insertions(+), 1 deletion(-)

diff --git a/doc/emacs/building.texi b/doc/emacs/building.texi
index 7074bd45d7..96af88b861 100644
--- a/doc/emacs/building.texi
+++ b/doc/emacs/building.texi
@@ -432,6 +432,10 @@ markers around matches for the purpose of highlighting.  You can make
 use of this feature by setting @code{grep-highlight-matches} to
 @code{t}.  When displaying a match in the source buffer, the exact
 match will be highlighted, instead of the entire source line.
+Highlighting is provided via matching of ANSI escape sequences emitted
+by Grep.  The matching of the sequences is controlled by
+@code{grep-match-regexp}, which can be customized to accommodate
+different grep programs.
 
   As with compilation commands (@pxref{Compilation}), while the grep
 command runs, the mode line shows the running number of matches found
diff --git a/etc/NEWS b/etc/NEWS
index b0c523672e..d2366fa7c4 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -176,6 +176,14 @@ was sent.  To restore the original behavior of dating a message
 from when it is first saved or delayed, add the symbol 'Date' back to
 this user option.
 
+** Grep changes:
+
+*** New variable 'grep-match-regexp' matches grep markers to highlight.
+Grep emits SGR ANSI escape sequences to color its output.  The new variable
+'grep-match-regexp' holds the regular expression to match the appropriate
+markers in order to provide highlighting in the source buffer.  The variable
+can be customized to accommodate other grep-like tools.
+
 ** Help
 
 +++
diff --git a/lisp/progmodes/grep.el b/lisp/progmodes/grep.el
index 7731be5965..8502744a8e 100644
--- a/lisp/progmodes/grep.el
+++ b/lisp/progmodes/grep.el
@@ -100,6 +100,13 @@ To change the default value, use \\[customize] or call the function
   :set #'grep-apply-setting
   :version "22.1")
 
+(defcustom grep-match-regexp "\033\\[0?1;31m\\(.*?\\)\033\\[[0-9]*m"
+  "Regular expression matching grep markers to highlight.
+It matches SGR ANSI escape sequences which are emitted by grep to
+color its output.  This variable is used in `grep-filter'."
+  :type 'regexp
+  :version "28.1")
+
 (defcustom grep-scroll-output nil
   "Non-nil to scroll the *grep* buffer window as output appears.
 
@@ -584,7 +591,7 @@ This function is called from `compilation-filter-hook'."
       (when (< (point) end)
         (setq end (copy-marker end))
         ;; Highlight grep matches and delete marking sequences.
-        (while (re-search-forward "\033\\[0?1;31m\\(.*?\\)\033\\[[0-9]*m" end 1)
+        (while (re-search-forward grep-match-regexp end 1)
           (replace-match (propertize (match-string 1)
                                      'face nil 'font-lock-face grep-match-face)
                          t t)
-- 
2.21.0 (Apple Git-122)

